## IOTile Transport Socket Library

This plugin library provides common message formats, packing routines and
other code that is useful for performing iotile operations via socket or 
socket-like protocols. Not particularily useful on it's own.